==============================
 Version 4.0.0 Release Notes
==============================

Solum 4.0.0 version release. This release includes
implementation of the app and workflow API resources
with their connection to end-to-end app deployment experience.

Specific feature include:

- App resource and app data format to represent an app
- Workflow resource to represent invocation of app deployment
- Logs resource and abstraction associated with workflow resource to represent app deployment logs
- App and workflow commands available in python-solumclient
- Improved output of languagepack list command by adding created_at attribute
